@@ -460,9 +460,9 @@ fn get_args_count(sig: &str) -> Result<usize, Error> {
     let mut num_args = 0;
     for substring in args {
         // leading or trailing ,'s or []
+        let substring = substring.trim_matches(|c| c == ']' || c == '[');
         let substring = substring.trim_matches(',');
-        let substring = substring.trim_matches(']');
-        let substring = substring.trim_matches('[');
+        let substring = substring.trim();
         if !substring.is_empty() {
             num_args += substring.split(',').count();
         }
@@ -807,7 +807,8 @@ mod tests {
             ("updateValset((address[],uint256[],uint256,uint256,address),(address[],uint256[],uint256,uint256,address),uint8[],bytes32[],bytes32[])", 13),
         ("submitLogicCall(address[],uint256[],uint256,uint8[],bytes32[],bytes32[],(uint256[],address[],uint256[],address[],address,bytes,uint256,bytes32,uint256))", 15),
         ("updateValset((address[],uint256[],uint256,uint256,address),(address[],uint256[],uint256,uint256,address),(uint8[],bytes32[],bytes32[]))", 13),
-        ("updateValset((address[],uint256[],uint256,uint256,address),(address[],uint256[],uint256,uint256,address),(uint8,bytes32,bytes32)[])", 13)
+        ("updateValset((address[],uint256[],uint256,uint256,address),(address[],uint256[],uint256,uint256,address),(uint8,bytes32,bytes32)[])", 13),
+        ("submitBatch((address[],uint256[],uint256,uint256,address),(uint8,bytes32,bytes32)[],uint256[],address[],uint256[],uint256,address,uint256)", 14)
         ];
         for (sig, count) in test_signatures.iter() {
             assert_eq!(get_args_count(sig).unwrap(), *count);
